`xoutil.deprecation`:mod: - Utils for marking deprecated elements
=================================================================

.. automodule:: xoutil.deprecation

.. autofunction:: deprecated(replacement, msg=None, deprecated_module=None, removed_in_version=None, check_version=False)

.. autofunction:: deprecated_alias

.. autofunction:: import_deprecated

.. autofunction:: deprecate_module

.. autofunction:: deprecate_linked
